@@ -1,10 +1,12 @@
 from .aws import AwsPrefixListDatasource
+from .jsonquery import JsonQueryListDatasource
 from .merge import MergePrefixListDatasource
 from .static import StaticPrefixListDatasource
 from .web import WebPrefixListDatasource
 
 __all__ = [
     "AwsPrefixListDatasource",
+    "JsonQueryListDatasource",
     "MergePrefixListDatasource",
     "StaticPrefixListDatasource",
     "WebPrefixListDatasource"
