@@ -2,10 +2,12 @@ from .junos_srx_address import JunosSrxAddress
 from .junos_srx_address_set import JunosSrxAddressSet
 from .junos_srx_application import JunosSrxApplication
 from .junos_srx_rule import JunosSrxRule
+from .junos_srx_datastructure import JunosSrxDatastructure
 
 __all__ = [
     "JunosSrxAddress",
     "JunosSrxAddressSet",
     "JunosSrxApplication",
-    "JunosSrxRule"
+    "JunosSrxRule",
+    "JunosSrxDatastructure"
 ]
